@@ -156,7 +156,7 @@ int main(int argc, char **argv)
     initsession(&ctx->session);
     ctx->msg = NULL;
 
-#if 0
+#if 1
     {
         char buf[1000];
         int bufused = 0;
@@ -648,7 +648,7 @@ static lmtp_rc_t lmtp_cb_rcpt(lmtp_t *lmtp, lmtp_io_t *io, lmtp_req_t *req, void
 
     if (ctx->option_groupmode == GROUPMODE_ENVELOPE) {
         //fprintf(stderr, "DEBUG: before transform cp=***%s***\n", cp);
-        if (!str_parse(cp, "m/^.+?\\+(.+)?@.+$/i", &group)) { //FIXME >=2 * @
+        if (!str_parse(cp, "m/^<(.+)?@[^@]+>$/i", &group)) {
             res.statuscode = "550";
             res.dsncode    = "5.1.1";
             res.statusmsg  = "Recipient did not transform into Group.";
